@@ -285,7 +285,9 @@ int main(int argc, char **argv)
 			if(!rfiStrategy::DefaultStrategy::StrategyContainsAction(*subStrategy, rfiStrategy::ForEachBaselineActionType) &&
 				!rfiStrategy::DefaultStrategy::StrategyContainsAction(*subStrategy, rfiStrategy::WriteFlagsActionType))
 			{
-				rfiStrategy::DefaultStrategy::EncapsulateSingleStrategy(*fomAction, std::move(subStrategy), rfiStrategy::DefaultStrategy::GENERIC_TELESCOPE);
+				rfiStrategy::DefaultStrategy::StrategySetup setup =
+					rfiStrategy::DefaultStrategy::DetermineSetup(rfiStrategy::DefaultStrategy::GENERIC_TELESCOPE, 0, 0.0, 0.0, 0.0);
+				rfiStrategy::DefaultStrategy::EncapsulateSingleStrategy(*fomAction, std::move(subStrategy), setup);
 				Logger::Info << "Modified single-baseline strategy so it will execute strategy on all baselines and write flags.\n";
 			}
 			else {
@@ -317,14 +319,14 @@ int main(int argc, char **argv)
 		
 		overallStrategy.InitializeAll();
 		overallStrategy.StartPerformThread(artifacts, progress);
-		rfiStrategy::ArtifactSet *set = overallStrategy.JoinThread();
+		std::unique_ptr<rfiStrategy::ArtifactSet> set = overallStrategy.JoinThread();
 		overallStrategy.FinishAll();
 
 		set->AntennaFlagCountPlot().Report();
 		set->FrequencyFlagCountPlot().Report();
 		set->PolarizationStatistics().Report();
 
-		delete set;
+		set.reset();
 
 		Logger::Debug << "Time: " << watch.ToString() << "\n";
 		
