@@ -58,12 +58,6 @@ namespace aoflagger {
 			/** @brief No flags: use the default strategy for the telescope. */
 			static const unsigned NONE;
 			
-			/** @brief Optimize for telescope's lower frequencies. */
-			static const unsigned LOW_FREQUENCY;
-			
-			/** @brief Optimize for telescope's higher frequencies. */
-			static const unsigned HIGH_FREQUENCY;
-
 			/** @brief Observation was made at larger bandwidth than common.
 			 * 
 			 * Depending on the telescope, this might e.g. try to divide frequency
@@ -94,22 +88,13 @@ namespace aoflagger {
 			/** @brief Optimize for speed at cost of accuracy and robustness. */
 			static const unsigned FAST;
 			
-			/** @brief Optimize for strong off-axis source in the observation.
-			 * 
-			 * Strong off-axis sources can create strong rapid fringes, which
-			 * (depending on observation resolution) might trigger the flagger
-			 * falsely. This is especially the case for widefield telescopes
-			 * where each station has a large collecting area, e.g.
-			 * the LOFAR LBA stations. */
-			static const unsigned OFF_AXIS_SOURCES;
-			
 			/** @brief Make the strategy less sensitive to RFI than the default
 			 * telescope settings.
 			 * 
 			 * Can be used if the flagger seems to destroy too much data. In this
 			 * case, you might consider also using @ref ROBUST instead.
 			 */
-			static const unsigned UNSENSITIVE;
+			static const unsigned INSENSITIVE;
 			
 			/** @brief Make the strategy more sensitive to RFI than the default
 			 * telescope settings. 
@@ -120,9 +105,11 @@ namespace aoflagger {
 			 */
 			static const unsigned SENSITIVE;
 			
-			/** @brief Will keep the background images in memory so they can be displayed
-			 * in the GUI. */
-			static const unsigned GUI_FRIENDLY;
+			/** @brief Will assume that the original flags that are already set in
+			 * the observation denote bad data and should be ignored. For example, certain
+			 * observatory correlators output flagged data when the data from an antenna is
+			 * (temporarily) not received. */
+			static const unsigned USE_ORIGINAL_FLAGS;
 			
 			/** @brief Erase any flags that are already set.
 			 * 
@@ -186,23 +173,23 @@ namespace aoflagger {
 			~ImageSet();
 			
 			/** @brief Assign to this image set. Only references to images are copied. */
-			ImageSet &operator=(const ImageSet& sourceImageSet);
+			ImageSet& operator=(const ImageSet& sourceImageSet);
 			
 			/** @brief Move assign to this image set.
 			 * @since Version 2.10
 			 */
-			ImageSet &operator=(ImageSet&& sourceImageSet);
+			ImageSet& operator=(ImageSet&& sourceImageSet);
 			
 			/** @brief Get access to the data buffer of an image.
 			 * @param imageIndex Index of image. See class description for ordering.
 			 * \note Rows are padded, see @ref HorizontalStride().
 			 */
-			float *ImageBuffer(size_t imageIndex);
+			float* ImageBuffer(size_t imageIndex);
 			
 			/** @brief Get constant access to the data buffer of an image.
 			 * @param imageIndex Index of image. See class description for ordering.
 			 */
-			const float *ImageBuffer(size_t imageIndex) const;
+			const float* ImageBuffer(size_t imageIndex) const;
 			
 			/** @brief Get width (number of time steps) of images. */
 			size_t Width() const;
@@ -230,7 +217,7 @@ namespace aoflagger {
 			
 			/** @brief Set all samples to the specified value.
 			 * @param newValue The new value for all values of all images in the set.
-			 * @since 2.5.0
+			 * @since 2.5
 			 */
 			void Set(float newValue);
 
@@ -243,7 +230,7 @@ namespace aoflagger {
 			 * to freeing and then allocating new images. It was added after rather
 			 * severe memory fragmentation problems in the Cotter MWA pipeline.
 			 * @param newWidth The new width of the images. Should satisfy newWidth <= HorizontalStride().
-			 * @since 2.5.0
+			 * @since 2.5
 			 */
 			void ResizeWithoutReallocation(size_t newWidth) const;
 			
@@ -258,7 +245,7 @@ namespace aoflagger {
 			
 			static void assertValidCount(size_t count);
 			
-			class ImageSetData *_data;
+			class ImageSetData* _data;
 	};
 
 	/** @brief A two-dimensional flag mask.
@@ -335,16 +322,16 @@ namespace aoflagger {
 			size_t HorizontalStride() const;
 			
 			/** @brief Get access to the data buffer. */
-			bool *Buffer();
+			bool* Buffer();
 			
 			/** @brief Get constant access to the data buffer. */
-			const bool *Buffer() const;
+			const bool* Buffer() const;
 			
 		private:
 			FlagMask(size_t width, size_t height);
 			FlagMask(size_t width, size_t height, bool initialValue);
 			
-			class FlagMaskData *_data;
+			class FlagMaskData* _data;
 	};
 
 	/** @brief Holds a flagging strategy.
@@ -372,19 +359,19 @@ namespace aoflagger {
 			~Strategy();
 			
 			/** @brief Assign to strategy. */
-			Strategy &operator=(const Strategy& sourceStrategy);
+			Strategy& operator=(const Strategy& sourceStrategy);
 			
 			/** @brief Move assign to strategy.
 			 * @since Version 2.10
 			 */
-			Strategy &operator=(Strategy&& sourceStrategy);
+			Strategy& operator=(Strategy&& sourceStrategy);
 			
 		private:
 			Strategy(enum TelescopeId telescopeId, unsigned strategyFlags, double frequency=0.0, double timeRes=0.0, double frequencyRes=0.0);
 			
 			explicit Strategy(const std::string& filename);
 			
-			class StrategyData *_data;
+			class StrategyData* _data;
 	};
 
 	/** @brief Statistics that can be collected online and saved to a measurement set.
@@ -424,7 +411,7 @@ namespace aoflagger {
 			~QualityStatistics();
 			
 			/** @brief Assign to this object. This is fast; only references are copied. */
-			QualityStatistics& operator=(const QualityStatistics &sourceQS);
+			QualityStatistics& operator=(const QualityStatistics& sourceQS);
 			
 			/** @brief Assign to this object. This is fast; only references are copied.
 			 * @since Version 2.10
@@ -440,12 +427,12 @@ namespace aoflagger {
 			 * count, etc.). When using this object again during collecting (see @ref AOFlagger::CollectStatistics()),
 			 * after combining it with another object, it will still use the meta data it was initialized with.
 			 */
-			QualityStatistics &operator+=(const QualityStatistics &rhs);
+			QualityStatistics& operator+=(const QualityStatistics& rhs);
 			
 		private:
-			QualityStatistics(const double *scanTimes, size_t nScans, const double *channelFrequencies, size_t nChannels, size_t nPolarizations, bool computeHistograms);
+			QualityStatistics(const double* scanTimes, size_t nScans, const double* channelFrequencies, size_t nChannels, size_t nPolarizations, bool computeHistograms);
 			
-			class QualityStatisticsData *_data;
+			class QualityStatisticsData* _data;
 	};
 	
 	/**
@@ -470,7 +457,7 @@ namespace aoflagger {
 			 * @param taskCount Total number of (sub) tasks.
 			 * @param description Description of the task, e.g. "SumThreshold".
 			 */
-			virtual void OnStartTask(size_t taskNo, size_t taskCount, const std::string &description)
+			virtual void OnStartTask(size_t taskNo, size_t taskCount, const std::string& description)
 			{ }
 			/**
 			* @brief Called when at the end of the current task.
@@ -495,7 +482,7 @@ namespace aoflagger {
 			 * This can occur when for example the strategy is malformed. 
 			 * @param thrownException The exception that was thrown.
 			 */
-			virtual void OnException(std::exception &thrownException) = 0;
+			virtual void OnException(std::exception& thrownException) = 0;
 	};
 	
 	/** @brief Main class for access to the flagger functionality.
@@ -595,7 +582,7 @@ namespace aoflagger {
 			 * of @ref ImageSet for image order).
 			 * @param widthCapacity Allow for enlarging image to this size, @sa ImageSet::ResizeWithoutReallocation()
 			 * @return A new ImageSet.
-			 * @since 2.6.0
+			 * @since 2.6
 			 */
 			ImageSet MakeImageSet(size_t width, size_t height, size_t count, size_t widthCapacity)
 			{
@@ -623,7 +610,7 @@ namespace aoflagger {
 			 * @param initialValue Initialize all pixels with this value.
 			 * @param widthCapacity Allow for enlarging image to this size, @sa ImageSet::ResizeWithoutReallocation()
 			 * @return A new ImageSet.
-			 * @since 2.6.0
+			 * @since 2.6
 			 */
 			ImageSet MakeImageSet(size_t width, size_t height, size_t count, float initialValue, size_t widthCapacity)
 			{
@@ -655,8 +642,8 @@ namespace aoflagger {
 			 * 
 			 * All parameters are hints to optimize the strategy, but need not actual alter the
 			 * strategy (or even have correct effects), but the returned strategy should for most
-			 * common cases be fine. Some properties conflict, e.g., specifying @ref StrategyFlags::LOW_FREQUENCY
-			 * as flag and giving a high @a frequency value. In these cases it is not defined which
+			 * common cases be fine. Some properties conflict, e.g., specifying @ref StrategyFlags::HIGH_TIME_RESOLUTION
+			 * as flag and giving a low @a timeRes value. In these cases it is not defined which
 			 * parameter takes precedence, thus it should obviously be avoided.
 			 * 
 			 * If frequency value, time resolution or frequency resolution or not known, they can be left at
@@ -700,13 +687,28 @@ namespace aoflagger {
 			 */
 			FlagMask Run(Strategy& strategy, const ImageSet& input);
 			
+			/** @brief Run the flagging strategy on the given data with correlator flags.
+			 * 
+			 * This method is similar to @ref Run(Strategy& strategy, const ImageSet&), except
+			 * that it will pass the correlator flags to the flagging strategy, which in the
+			 * case of bad data can do a better job of finding RFI in the good data.
+			 * @p input parameter. The @p strategy parameter can be the
+			 * same for different threads.
+			 * @param strategy The flagging strategy that will be used.
+			 * @param input The data to run the flagger on.
+			 * @param correlatorFlags Flags that indicate what data are bad.
+			 * @return The flags identifying bad (RFI contaminated) data.
+			 * @since 2.12
+			 */
+			FlagMask Run(Strategy& strategy, const ImageSet& input, const FlagMask& correlatorFlags);
+			
 			/** @brief Create a new object for collecting statistics.
 			 * 
 			 * See the QualityStatistics class description for info on multithreading and/or combining statistics
 			 * with different meta data. The meta data that is passed to this method will be used for all
 			 * calls to CollectStatistics() if this class is specified. No histograms will be computed.
 			 */
-			QualityStatistics MakeQualityStatistics(const double *scanTimes, size_t nScans, const double *channelFrequencies, size_t nChannels, size_t nPolarizations);
+			QualityStatistics MakeQualityStatistics(const double* scanTimes, size_t nScans, const double* channelFrequencies, size_t nChannels, size_t nPolarizations);
 			
 			/** @brief Create a new object for collecting statistics, possibly with histograms.
 			 * 
@@ -715,7 +717,7 @@ namespace aoflagger {
 			 * calls to CollectStatistics() if this class is specified.
 			 * @since Version 2.6
 			 */
-			QualityStatistics MakeQualityStatistics(const double *scanTimes, size_t nScans, const double *channelFrequencies, size_t nChannels, size_t nPolarizations, bool computeHistograms);
+			QualityStatistics MakeQualityStatistics(const double* scanTimes, size_t nScans, const double* channelFrequencies, size_t nChannels, size_t nPolarizations, bool computeHistograms);
 			
 			/** @brief Collect statistics from time-frequency images and masks.
 			 * 
@@ -776,7 +778,7 @@ namespace aoflagger {
 			 * events and call this method to enable receiving the events.
 			 * This method is not thread safe.
 			 * @param statusListener The handler that will receive the status updates.
-			 * @since Version 2.6.2
+			 * @since Version 2.7
 			 */
 			void SetStatusListener(StatusListener* statusListener)
 			{
