@@ -1,36 +1,6 @@
 #include "strategywriter.h"
 
-#include "../actions/absthresholdaction.h"
-#include "../actions/baselineselectionaction.h"
-#include "../actions/calibratepassbandaction.h"
-#include "../actions/changeresolutionaction.h"
-#include "../actions/combineflagresultsaction.h"
-#include "../actions/cutareaaction.h"
-#include "../actions/eigenvalueverticalaction.h"
-#include "../actions/foreachbaselineaction.h"
-#include "../actions/foreachcomplexcomponentaction.h"
-#include "../actions/foreachmsaction.h"
-#include "../actions/foreachpolarisationaction.h"
-#include "../actions/frequencyconvolutionaction.h"
-#include "../actions/frequencyselectionaction.h"
-#include "../actions/fringestopaction.h"
-#include "../actions/imageraction.h"
-#include "../actions/iterationaction.h"
-#include "../actions/highpassfilteraction.h"
-#include "../actions/normalizevarianceaction.h"
-#include "../actions/plotaction.h"
-#include "../actions/quickcalibrateaction.h"
-#include "../actions/setflaggingaction.h"
-#include "../actions/setimageaction.h"
-#include "../actions/slidingwindowfitaction.h"
-#include "../actions/statisticalflagaction.h"
-#include "../actions/strategy.h"
-#include "../actions/svdaction.h"
-#include "../actions/sumthresholdaction.h"
-#include "../actions/timeconvolutionaction.h"
-#include "../actions/timeselectionaction.h"
-#include "../actions/writedataaction.h"
-#include "../actions/writeflagsaction.h"
+#include "../actions/all.h"
 
 #include "../../version.h"
 
@@ -147,7 +117,7 @@ namespace rfiStrategy {
 				writeSlidingWindowFitAction(static_cast<const SlidingWindowFitAction&>(action));
 				break;
 			case StatisticalFlagActionType:
-				writeStatisticalFlagAction(static_cast<const StatisticalFlagAction&>(action));
+				writeMorphologicalFlagAction(static_cast<const MorphologicalFlagAction&>(action));
 				break;
 			case StrategyType:
 				writeStrategy(static_cast<const Strategy&>(action));
@@ -164,6 +134,9 @@ namespace rfiStrategy {
 			case TimeSelectionActionType:
 				writeTimeSelectionAction(static_cast<const TimeSelectionAction&>(action));
 				break;
+			case VisualizeActionType:
+				writeVisualizeAction(static_cast<const VisualizeAction&>(action));
+				break;
 			case WriteDataActionType:
 				writeWriteDataAction(static_cast<const WriteDataAction&>(action));
 				break;
@@ -387,7 +360,7 @@ namespace rfiStrategy {
 		Write<int>("time-direction-window-size", action.Parameters().timeDirectionWindowSize);
 	}
 
-	void StrategyWriter::writeStatisticalFlagAction(const StatisticalFlagAction &action)
+	void StrategyWriter::writeMorphologicalFlagAction(const MorphologicalFlagAction &action)
 	{
 		Attribute("type", "StatisticalFlagAction");
 		Write<size_t>("enlarge-frequency-size", action.EnlargeFrequencySize());
@@ -397,6 +370,7 @@ namespace rfiStrategy {
 		Write<num_t>("min-available-tf-ratio", action.MinAvailableTFRatio());
 		Write<num_t>("minimum-good-frequency-ratio", action.MinimumGoodFrequencyRatio());
 		Write<num_t>("minimum-good-time-ratio", action.MinimumGoodTimeRatio());
+		Write<bool>("exclude-original-flags", action.ExcludeOriginalFlags());
 	}
 
 	void StrategyWriter::writeStrategy(const class Strategy &action)
@@ -418,6 +392,7 @@ namespace rfiStrategy {
 		Write<num_t>("frequency-direction-sensitivity", action.FrequencyDirectionSensitivity());
 		Write<bool>("time-direction-flagging", action.TimeDirectionFlagging());
 		Write<bool>("frequency-direction-flagging", action.FrequencyDirectionFlagging());
+		Write<bool>("exclude-original-flags", action.ExcludeOriginalFlags());
 	}
 
 	void StrategyWriter::writeTimeConvolutionAction(const TimeConvolutionAction &action)
@@ -437,6 +412,26 @@ namespace rfiStrategy {
 		Attribute("type", "TimeSelectionAction");
 		Write<double>("threshold", action.Threshold());
 	}
+	
+	void StrategyWriter::writeVisualizeAction(const VisualizeAction& action)
+	{
+		Attribute("type", "VisualizeAction");
+		Write("label", action.Label());
+		switch(action.Source())
+		{
+			default:
+			case VisualizeAction::FromOriginal:
+				Write("source", "original");
+				break;
+			case VisualizeAction::FromRevised:
+				Write("source", "revised");
+				break;
+			case VisualizeAction::FromContaminated:
+				Write("source", "contaminated");
+				break;
+		}
+		Write("sorting-index", action.SortingIndex());
+	}
 
 	void StrategyWriter::writeWriteDataAction(const WriteDataAction &)
 	{
